@@ -932,7 +932,7 @@ void ac_format(struct qrv_item *qi, char *acstart, char *acint, int flags){
             if (flags & 1)
                 sprintf(acstart, "%02d:%02d:%02d %02dm%02d", utc.tm_hour, utc.tm_min, utc.tm_sec, (int)((diff / 60) % 60), (int)(diff / 60));
             else
-                sprintf(acstart, "%02dm%02d", (int)((diff / 60) % 60), (int)(diff / 60));
+                sprintf(acstart, "%02dm%02d", (int)((diff / 60) % 60), (int)(diff % 60));
         }
         //dbg("%s: %02d:%02d:%02d start=%3ld diff=%3ld\n", qi->call, utc.tm_hour, utc.tm_min, utc.tm_sec, (long)(qi->ac_start % 60), (long)diff);
         //dbg("%s: start=%ld  now=%ld  -=%ld  diff=%ld\n", qi->call, (long)qi->ac_start % 1000, (long)time(NULL) % 1000, (long)qi->ac_start - (long)time(NULL), (long)diff);
