@@ -468,7 +468,10 @@ gpointer cwdaemon_thread_func(gpointer data){
             for (i=0;i<ret;i++){
                 if (buf[i]>=' ') {
                     if (cwda->code->len == 0 && qi<0){
-                        if (cwda->ptt && !cwda->hold_ptt) cwda->ptt(cwda, 1);
+                        if (cwda->ptt && !cwda->hold_ptt) {
+							cwda->ptt(cwda, 1);
+							zselect_msg_send(zsel, "CW;p"); // Rig PTT ON request
+						}
                         if (!cwda->hold_ptt) g_string_append_c(cwda->code, '\x09');
                     }
                     g_string_append_c(cwda->code, z_char_uc(buf[i]));
@@ -549,6 +552,11 @@ void cwdaemon_read_handler(struct cwdaemon *cwda, char *s, char *played){
             cq_abort(SSBDRECORDING); /*abort recording only if it is in progress */
             log_addf("cwdaemon: %s", s+1);
             break;
+		case 'p':  // Rig PTT ON request
+#ifdef HAVE_HAMLIB
+			trigs_set_ptt(gtrigs, 1);
+#endif
+			break;
         case 'e':  /* cw text played */
             if (aband){
                 dbg("cwdaemon_read_handler: call_played='%s' agcall=%d iscall='%d'\n", aband->call_played, aband->agcall, aband->iscall);
@@ -640,6 +648,9 @@ void cwdaemon_abort(struct cwdaemon *cwda){
     cwda->tune = 0;
     z_pipe_write(cwda->pipe_write, "\x03", 1);
 
+#ifdef HAVE_HAMLIB
+	trigs_set_ptt(gtrigs, 0);
+#endif
 	//dbg("cwdaemon_abort returned\n");
 }
 
@@ -660,14 +671,14 @@ int cwdaemon_text(struct cwdaemon *cwda, char *text){
 }
 
 void cwdaemon_ptt(struct cwdaemon *cwda, int ptt, int hold_ptt){
-    
-    if (!cwda || !cwda->ptt) return;
-    /*dbg("ptt %d\n", ptt);*/
-    cwda->hold_ptt = hold_ptt;
-    cwda->ptt(cwda, ptt);        
-    if (cwda->hold_ptt) g_string_append_c(cwda->code, '\x09');
+	/*dbg("ptt %d\n", ptt);*/
+    if (cwda && cwda->ptt){ 
+		cwda->hold_ptt = hold_ptt;
+		cwda->ptt(cwda, ptt);        
+		if (cwda->hold_ptt) g_string_append_c(cwda->code, '\x09');
+	}
 #ifdef HAVE_HAMLIB
-	trigs_set_ptt(gtrigs, ptt ? RIG_PTT_ON : RIG_PTT_OFF);
+	trigs_set_ptt(gtrigs, ptt);
 #endif
 }
 
@@ -1067,6 +1078,10 @@ int cq_run_ssb(struct cq *cq){
     gssbd->pfilename=convert_esc(cq->ssb_file, NULL, CE_NONE, time(NULL));
     if (!gssbd->pfilename) return -1;
     ret=ssbd_play_file(gssbd, gssbd->pfilename);
+	if (ret < 0) {
+		cq_abort(0);
+		return ret;
+	}
 #endif
 
     gses->last_cq = cq;
@@ -1077,6 +1092,7 @@ int cq_run_ssb(struct cq *cq){
 #else
     log_adds("Tucnak is compiled without libsndfile, no SSB CQ available");
 #endif
+	return -1;
 }
 
 #if defined(HAVE_SNDFILE) || defined(Z_ANDROID)
