@@ -122,6 +122,21 @@ void add_qso_str3(GString *gs, struct qso *q, struct band *b){
 }
 
 
+const char *get_psect_str(struct band *b){
+	switch(b->psect){
+		case 0:
+			return "Multi";
+		case 1:
+			return "Single";
+		case 2:
+			return "Check";
+		default:
+			return b->opsect;
+	}
+}
+
+
+
 static int write_edi_header(struct band *b, struct config_band *confb, FILE *f){
     char s[1024];
     GString *gs;
@@ -140,20 +155,7 @@ static int write_edi_header(struct band *b, struct config_band *confb, FILE *f){
     g_string_sprintfa(gs, "PExch=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pexch, 69)));
     g_string_sprintfa(gs, "PAdr1=%s\r\n",    safe_strncpy0(s, ctest->padr1, 69));
     g_string_sprintfa(gs, "PAdr2=%s\r\n",    safe_strncpy0(s, ctest->padr2, 69));
-	switch(b->psect){
-		case 0:
-			g_string_sprintfa(gs, "PSect=Multi\r\n");
-			break;
-		case 1:
-			g_string_sprintfa(gs, "PSect=Single\r\n");
-			break;
-		case 2:
-			g_string_sprintfa(gs, "PSect=Check\r\n");
-			break;
-		default:
-			g_string_sprintfa(gs, "PSect=%s\r\n", b->opsect);
-			break;
-	}
+	g_string_sprintfa(gs, "PSect=%s\r\n", get_psect_str(b));
     g_string_sprintfa(gs, "PBand=%s\r\n", b->pband);
     g_string_sprintfa(gs, "PClub=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pclub, 69)));
     g_string_sprintfa(gs, "RName=%s\r\n",    safe_strncpy0(s, ctest->rname, 69));
