@@ -243,6 +243,10 @@ void read_exc_files(struct excdb *excdb, enum exctype exctype, gchar *excname){
             ret = load_vexc_from_mem(excdb, txt_tucnakvexcusaca, sizeof(txt_tucnakvexcusaca));
             dbg("    %s %d\n", ename, ret);
         }
+        if (strcasecmp(ename, "kac")==0) {
+            ret = load_vexc_from_mem(excdb, txt_tucnakvexckac, sizeof(txt_tucnakvexckac));
+            dbg("    %s %d\n", ename, ret);
+        }
     }
     g_free(ename);
 
