@@ -691,7 +691,7 @@ static void init(void)
     ntpq = init_ntpq();        
 #endif
 #ifdef HAVE_HAMLIB
-    gtrigs = init_trigs();        
+    init_trigs();        
 #endif
 #ifdef USE_FFT
 	gfft = init_fft();
@@ -788,6 +788,7 @@ static void terminate_all_subsystems(void)
 #endif
 #ifdef HAVE_HAMLIB
     free_trigs(gtrigs); 
+	gtrigs = NULL;
 #endif
 #ifdef Z_UNIX
     free_ntpq(ntpq); 
