@@ -1330,7 +1330,7 @@ void map_recalc_gst(struct subwin *sw, struct band *band){
     for (i=0; i<360; i++) sw->gst[i] = sw->gst[i] / max; 
 } 
 
-int plot_hgt(struct subwin *sw, SDL_Rect *area, int xx, int yy, char *file)
+void plot_hgt(struct subwin *sw, SDL_Rect *area, int xx, int yy, char *file)
 {
 	char s[256];
 	FILE *f;
