@@ -69,12 +69,14 @@ char ok_section_single[RESP_LEN], ok_section_multi[RESP_LEN];
 char qrg_min_str[RESP_LEN], qrg_max_str[RESP_LEN];
 char adifband[RESP_LEN], skedqrg[RESP_LEN], band_lo_str[RESP_LEN];
 char band_sw_str[RESP_LEN];
+char wwlradius_str[RESP_LEN];
 
 //int bandfirstbutt;
 
 void refresh_band_confb(void *xxx)
 {
     struct config_band *confb;
+    struct band *band;
         
 /*    dbg("refresh_band_confb\n");    */
     confb=(struct config_band *)xxx;
@@ -104,6 +106,18 @@ void refresh_band_confb(void *xxx)
     STORE_STR(confb, skedqrg);
     STORE_SDBL(confb, band_lo);
     STORE_SHEX(confb, band_sw);
+    STORE_SINT(confb, wwlradius);
+    
+    band = find_band_by_pband(confb->pband);
+    if (band != NULL){
+        int oldwwlradius = band->wwlradius;
+        STORE_SINT(band, wwlradius);
+        if (band->wwlradius != oldwwlradius) {
+            band->dirty_statsf = 1;
+            recalc_statsfifo(band);
+        }
+
+    }
 }
 
 void refresh_band(void *xxx)
@@ -213,6 +227,7 @@ void band_settings(void *arg, int from_ctest)
         safe_strncpy0(skedqrg,confb->skedqrg,RESP_LEN);
         g_snprintf(band_lo_str, RESP_LEN, "%1.1f", confb->band_lo);
         g_snprintf(band_sw_str, RESP_LEN, "0x%02x", confb->band_sw);
+        g_snprintf(wwlradius_str, RESP_LEN, "%d", confb->wwlradius);
     }else{
         qrvnow=1;
         psect=band->psect;
@@ -233,7 +248,11 @@ void band_settings(void *arg, int from_ctest)
         g_snprintf(qrg_max, RESP_LEN, "%d", band->qrg_max);
         safe_strncpy0(adifband,band->adifband,RESP_LEN);
         safe_strncpy0(skedqrg,band->skedqrg,RESP_LEN);
-        g_snprintf(band_lo, RESP_LEN, "%1.1f", band->band_lo);*/
+        g_snprintf(band_lo, RESP_LEN, "%1.1f", band->band_lo);
+        band_sw
+        wwlradius 
+         */
+
     }
 
     if (!(d = (struct dialog *)g_malloc(sizeof(struct dialog) + 55 * sizeof(struct dialog_item)))) return;
@@ -410,6 +429,12 @@ void band_settings(void *arg, int from_ctest)
         d->items[i].dlen = 6;
         d->items[i].data = band_sw_str;
 		d->items[i].msg = CTEXT(T_BANDSW);
+	    //d->items[i].wrap = 2;
+
+        d->items[++i].type = D_FIELD;      
+        d->items[i].dlen = 6;
+        d->items[i].data = wwlradius_str;
+		d->items[i].msg = TRANSLATE("Stats WWL radius:");
 	    d->items[i].wrap = 2;
 
     }
