@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2012-2015 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2012-2016 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -410,7 +410,7 @@ void menu_ac_opts(void *arg){
 
 }
 
-/**************************** DSP ****************************************/
+/**************************** SDR ****************************************/
 
 int sdr_enable, sdr_rec_dsp_type, sdr_play_dsp_type;
 char sdr_speed_str[EQSO_LEN];
@@ -426,11 +426,12 @@ int sdr_pa_rec, sdr_pa_play;
 char sdr_pa_rec_src[MAX_STR_LEN], sdr_pa_play_src[MAX_STR_LEN];
 
 #ifdef HAVE_SNDFILE
-char sdr_sndfilename[MAX_STR_LEN];
+char sdr_sndfilename[MAX_STR_LEN], sdr_af_filename[MAX_STR_LEN];
 #endif
-char new_sdr_sndfilename[MAX_STR_LEN];
+char new_sdr_sndfilename[MAX_STR_LEN], new_sdr_af_filename[MAX_STR_LEN];
+char sdr_remoterx[MAX_STR_LEN];
 
-int sdr_sndfilename_index = -1;
+int sdr_sndfilename_index = -1, sdr_af_filename_index = -1;
 int sdr_samplerate_index = -1;
 int sdr_af_samplerate_index = -1;
 
@@ -497,6 +498,7 @@ static int dlg_pa_play_src(struct dialog_data *dlg, struct dialog_item_data *di)
 
 #ifdef HAVE_SNDFILE
 
+// IQ filename
 void refresh_sdr_sndfilename(void *xxx, char *filename){
 	g_strlcpy(new_sdr_sndfilename, filename, MAX_STR_LEN);
 	redraw_later();
@@ -506,6 +508,17 @@ static int dlg_sdr_sndfilename(struct dialog_data *dlg, struct dialog_item_data
 	zfiledlg_open(zfiledlg, zsel, refresh_sdr_sndfilename, di, "", "wav");
 	return 0;
 }
+
+// AF filename
+void refresh_sdr_af_filename(void *xxx, char *filename){
+	g_strlcpy(new_sdr_af_filename, filename, MAX_STR_LEN);
+	redraw_later();
+}
+
+static int dlg_sdr_af_filename(struct dialog_data *dlg, struct dialog_item_data *di){
+	zfiledlg_open(zfiledlg, zsel, refresh_sdr_af_filename, di, "", "wav");
+	return 0;
+}
 #endif
 
 
@@ -516,8 +529,14 @@ void sdr_opts_fn(struct dialog_data *dlg)
         safe_strncpy0(dlg->items[sdr_sndfilename_index].cdata, new_sdr_sndfilename, MAX_STR_LEN);
 		dlg->items[sdr_sndfilename_index].cpos = strlen(new_sdr_sndfilename);
         strcpy(new_sdr_sndfilename, "");
+    }
+	if (strlen(new_sdr_af_filename)>0 && sdr_af_filename_index >= 0){
+        safe_strncpy0(dlg->items[sdr_af_filename_index].cdata, new_sdr_af_filename, MAX_STR_LEN);
+		dlg->items[sdr_af_filename_index].cpos = strlen(new_sdr_af_filename);
+        strcpy(new_sdr_af_filename, "");
     }
 	input_field_fn_i(dlg, sdr_sndfilename_index);
+	input_field_fn_i(dlg, sdr_af_filename_index);
 }
 
 
@@ -539,6 +558,14 @@ void refresh_sdr_opts(void *arg){
     STORE_SDBL(cfg, sdr_ssb_low);
     STORE_SDBL(cfg, sdr_ssb_high);
 
+#ifdef HAVE_SNDFILE
+	STORE_STR(cfg, sdr_sndfilename);
+	z_unix(sdr_sndfilename);
+	STORE_STR(cfg, sdr_af_filename);
+	z_unix(sdr_af_filename);
+#endif
+	STORE_STR(cfg, sdr_remoterx);
+
 #ifdef USE_SDR
     if (sdl){
         free_sdr(gsdr);
@@ -550,10 +577,8 @@ void refresh_sdr_opts(void *arg){
         }
     }
 #endif
-#ifdef HAVE_SNDFILE
-	STORE_STR(cfg, sdr_sndfilename);
-	z_unix(sdr_sndfilename);
-#endif
+
+
 	progress(NULL);
 }
 
@@ -651,8 +676,12 @@ void menu_sdr_opts(void *arg){
 #ifdef HAVE_SNDFILE
 	LOAD_STR(cfg, sdr_sndfilename);
 	z_wokna(sdr_sndfilename);
+	LOAD_STR(cfg, sdr_af_filename);
+	z_wokna(sdr_af_filename);
 #endif
 	strcpy(new_sdr_sndfilename, "");
+	strcpy(new_sdr_af_filename, "");
+	LOAD_STR(cfg, sdr_remoterx);
 
     d = (struct dialog *)g_malloc(sizeof(struct dialog) + 50 * sizeof(struct dialog_item));
     memset(d, 0, sizeof(struct dialog) + 50 * sizeof(struct dialog_item));
@@ -699,6 +728,14 @@ void menu_sdr_opts(void *arg){
     d->items[i].data = (char *)&sdr_rec_dsp_type;
     d->items[i].msg = CTEXT(T_WAV_FILE);
 #endif
+
+	d->items[++i].type = D_CHECKBOX;
+    d->items[i].gid = 1;
+	d->items[i].gnum = DSPT_SDRC;
+    d->items[i].dlen = sizeof(int);
+    d->items[i].data = (char *)&sdr_rec_dsp_type;
+    d->items[i].msg = TRANSLATE("Remote RX");
+
     d->items[i].wrap++;  //-------------------------------------
 	
     d->items[++i].type = D_FIELD;
@@ -742,6 +779,8 @@ void menu_sdr_opts(void *arg){
     d->items[i].msg = CTEXT(T_PA_REC);
 	d->items[i].wrap = 1;
 #endif
+
+
     
 #ifdef HAVE_SNDFILE
     d->items[++i].type = D_FIELD;
@@ -761,7 +800,16 @@ void menu_sdr_opts(void *arg){
 	d->items[i].wrap++;
 #endif
 #endif
+
+	d->items[++i].type = D_FIELD;
+    d->items[i].dlen = EQSO_LEN;
+    d->items[i].data = sdr_remoterx;
+    d->items[i].maxl = 39;
+    d->items[i].msg = TRANSLATE("Remote RX host");
+	d->items[i].wrap = 1;
+
 	d->items[i].wrap++;	  // ========================================================
+
 	
 	d->items[++i].type = D_TEXT;  
 	d->items[i].msg = CTEXT(T_AF_OUTPUT);
@@ -784,15 +832,16 @@ void menu_sdr_opts(void *arg){
     d->items[i].msg = CTEXT(T_PORTAUDIO);
 #endif
 
-/*#ifdef HAVE_SNDFILE
+#ifdef HAVE_SNDFILE
     d->items[++i].type = D_CHECKBOX;
     d->items[i].gid = 2;
 	d->items[i].gnum = DSPT_SNDFILE;
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (char *)&sdr_play_dsp_type;
     d->items[i].msg = CTEXT(T_WAV_FILE);
-#endif*/
+#endif
 
+	
     d->items[i].wrap++;  // ------------------------------------------------
 	
     d->items[++i].type = D_FIELD;
@@ -824,7 +873,26 @@ void menu_sdr_opts(void *arg){
     d->items[i].msg = CTEXT(T_PA_PLAY);
 	d->items[i].wrap = 1;
 #endif
+ #ifdef HAVE_SNDFILE
+    d->items[++i].type = D_FIELD;
+    d->items[i].dlen = MAX_STR_LEN;
+    d->items[i].data = sdr_af_filename;
+    d->items[i].maxl = 40;
+    d->items[i].msg = CTEXT(T_WAV_FILE_NAME);
+	d->items[i].tabcompl = 1;
+	sdr_af_filename_index = i;
 
+#ifdef Z_HAVE_SDL
+	if (sdl){
+		d->items[++i].type = D_BUTTON;  
+		d->items[i].fn   = dlg_sdr_af_filename;
+		d->items[i].text = CTEXT(T_RIG_CHOOSE);
+	}
+	d->items[i].wrap++;
+#endif
+#endif
+
+	
 	d->items[i].wrap++;	  // ========================================================
 
     d->items[++i].type = D_FIELD;
@@ -854,7 +922,7 @@ void menu_sdr_opts(void *arg){
     d->items[i].gid  = -10000;
     d->items[i].gnum = +10000;
     d->items[i].msg = CTEXT(T_TO_HZ); 
-	d->items[i].wrap = 1;
+	d->items[i].wrap = 1;// ------------------------------------------------
     
     d->items[++i].type = D_FIELD;
     d->items[i].dlen = EQSO_LEN;
@@ -873,7 +941,7 @@ void menu_sdr_opts(void *arg){
     d->items[i].gid  = -10000;
     d->items[i].gnum = +10000;
     d->items[i].msg = CTEXT(T_TO_HZ); 
-	d->items[i].wrap = 1;
+	d->items[i].wrap = 1; // ------------------------------------------------
     
     
     
