@@ -297,6 +297,7 @@ struct band *init_band(struct config_band *confb, GHashTable *opt_band, struct z
         b->remarks = g_strdup(confb->remarks);
         b->skedqrg = g_strdup(confb->skedqrg);
         b->band_sw = confb->band_sw;
+        b->wwlradius = confb->wwlradius;
 
 /*        struct zstring *zs = config_band_format(confb);
         dbg("zs='%s'\n", zs->str);
@@ -322,6 +323,7 @@ struct band *init_band(struct config_band *confb, GHashTable *opt_band, struct z
             b->qrg_min = tmpconfb->qrg_min;
             b->qrg_max = tmpconfb->qrg_max;
             b->band_sw = tmpconfb->band_sw;
+            b->wwlradius = tmpconfb->wwlradius;
         }else{
             // contest created under other band configuration
             b->bandname = g_strdup(b->pband);
@@ -732,7 +734,7 @@ void add_error(struct band *b, gchar *remark){
     struct tm utc;
 
     if (!ctest && !b) return;
-    if (b->readonly) return;
+    if (b->readonly) return;    
 
     log_addf(VTEXT(T_ADDED_ERROR), b->bandchar, b->qsos->len+1);
     
@@ -768,7 +770,7 @@ void add_error(struct band *b, gchar *remark){
     minute_stats(b);
     recalc_statsfifo(b);
     
-    if (b->qsos->len+1 != atoi(b->tmpqsos[0].qsonrs)){
+    if (b->tmpqsos[0].qsonrs != NULL && b->qsos->len+1 != atoi(b->tmpqsos[0].qsonrs)){
         g_free(b->tmpqsos[0].qsonrs);
         if (ctest->qsoused)
             b->tmpqsos[0].qsonrs = g_strdup_printf("%03d", b->qsos->len+1);
@@ -1264,7 +1266,7 @@ void dump_qso(struct qso *q, char *desc){
         return;
     }
    /* trace(cfg->trace_qsos, "  %8s %c%03d %s:%d.%05d  %s", q->callsign, z_char_uc(q->band->bandchar), atoi(q->qsonrs), q->source, q->ser_id, q->stamp%100000, desc);*/
-    trace(cfg->trace_qsos, "  %8s %c%03d %s:%d.%05d  (qsop=%d error=%d dupe=%d) %s", q->callsign, q->band->bandchar, atoi(q->qsonrs), q->source, q->ser_id, q->stamp%100000, q->qsop, q->error, q->dupe,  desc);
+    trace(cfg->trace_qsos, "  %8s %c%03d %s:%d.%05d  (qsop=%d error=%d dupe=%d) %s", q->callsign, q->band->bandchar, atoi(q->qsonrs), q->source, q->ser_id, (int)(q->stamp%100000), q->qsop, q->error, q->dupe,  desc);
 }
 
 void invalidate_tmpqso(struct band *b, struct qso *q){
