@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2016  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -89,6 +89,7 @@ enum {
     SYMBOL_BAND_LO      = G_TOKEN_LAST + 52,
     SYMBOL_BAND_SW      = G_TOKEN_LAST + 53,
     SYMBOL_OPSECT       = G_TOKEN_LAST + 54,
+    SYMBOL_WWLRADIUS    = G_TOKEN_LAST + 55,
     
     SYMBOL_AS_DAQ       = G_TOKEN_LAST + 60,
     SYMBOL_AS_DAM       = G_TOKEN_LAST + 61,
@@ -202,22 +203,23 @@ enum {
     SYMBOL_SW_AUTORUN        = G_TOKEN_LAST + 173,
     SYMBOL_SW_RESPAWN_TIME   = G_TOKEN_LAST + 174,
     
-	SYMBOL_RIG               = G_TOKEN_LAST + 180,
-	SYMBOL_RIG_ENABLED       = G_TOKEN_LAST + 181, 
-	SYMBOL_RIG_DESC			 = G_TOKEN_LAST + 182,
-    SYMBOL_RIG_FILENAME      = G_TOKEN_LAST + 183,
-    SYMBOL_RIG_MODEL         = G_TOKEN_LAST + 184,
-    SYMBOL_RIG_SPEED         = G_TOKEN_LAST + 185,
-    SYMBOL_RIG_CIVADDR       = G_TOKEN_LAST + 186,
-    SYMBOL_RIG_LO            = G_TOKEN_LAST + 187,
-    SYMBOL_RIG_SSBCW_SHIFT   = G_TOKEN_LAST + 188,
-    SYMBOL_RIG_POLL_MS       = G_TOKEN_LAST + 189,
-    SYMBOL_RIG_QRG_R2T       = G_TOKEN_LAST + 190,
-    SYMBOL_RIG_QRG_T2R       = G_TOKEN_LAST + 191,
-    SYMBOL_RIG_MODE_T2R      = G_TOKEN_LAST + 192,
-    SYMBOL_RIG_CLR_RIT       = G_TOKEN_LAST + 193,
-	SYMBOL_RIG_PTT_T2R       = G_TOKEN_LAST + 194,
-    SYMBOL_RIG_VERBOSE       = G_TOKEN_LAST + 195,
+	SYMBOL_RIG                = G_TOKEN_LAST + 180,
+	SYMBOL_RIG_ENABLED        = G_TOKEN_LAST + 181, 
+	SYMBOL_RIG_DESC			  = G_TOKEN_LAST + 182,
+    SYMBOL_RIG_FILENAME       = G_TOKEN_LAST + 183,
+    SYMBOL_RIG_MODEL          = G_TOKEN_LAST + 184,
+    SYMBOL_RIG_SPEED          = G_TOKEN_LAST + 185,
+	SYMBOL_RIG_HANDSHAKE_NONE = G_TOKEN_LAST + 186,
+    SYMBOL_RIG_CIVADDR        = G_TOKEN_LAST + 187,
+    SYMBOL_RIG_LO             = G_TOKEN_LAST + 188,
+    SYMBOL_RIG_SSBCW_SHIFT    = G_TOKEN_LAST + 189,
+    SYMBOL_RIG_POLL_MS        = G_TOKEN_LAST + 190,
+    SYMBOL_RIG_QRG_R2T        = G_TOKEN_LAST + 191,
+    SYMBOL_RIG_QRG_T2R        = G_TOKEN_LAST + 192,
+    SYMBOL_RIG_MODE_T2R       = G_TOKEN_LAST + 193,
+    SYMBOL_RIG_CLR_RIT        = G_TOKEN_LAST + 194,
+	SYMBOL_RIG_PTT_T2R        = G_TOKEN_LAST + 195,
+    SYMBOL_RIG_VERBOSE        = G_TOKEN_LAST + 196,
 
     SYMBOL_LOGLINES          = G_TOKEN_LAST + 200,
     SYMBOL_SKEDCOUNT         = G_TOKEN_LAST + 202,
@@ -239,6 +241,7 @@ enum {
 	SYMBOL_NOLOCKS			 = G_TOKEN_LAST + 218,
 	SYMBOL_PORTRAIT			 = G_TOKEN_LAST + 219,
 	SYMBOL_REVERSE			 = G_TOKEN_LAST + 220,
+	SYMBOL_INVERSE			 = G_TOKEN_LAST + 221,
 
 	SYMBOL_DXC_HOST			 = G_TOKEN_LAST + 230,
 	SYMBOL_DXC_PORT			 = G_TOKEN_LAST + 231,
@@ -280,6 +283,9 @@ enum {
 	SYMBOL_SDR_PCM_REC       = G_TOKEN_LAST + 275,
 	SYMBOL_SDR_PCM_PLAY      = G_TOKEN_LAST + 276,
 	SYMBOL_SDR_SNDFILENAME   = G_TOKEN_LAST + 277,
+	SYMBOL_SDR_REMOTERX      = G_TOKEN_LAST + 278,
+	SYMBOL_SDR_AF_FILENAME   = G_TOKEN_LAST + 279,
+	SYMBOL_SDR_IQCOMP        = G_TOKEN_LAST + 280,
 
 	SYMBOL_WIKI_URL          = G_TOKEN_LAST + 290,
 	SYMBOL_WIKI_USER         = G_TOKEN_LAST + 291,
@@ -352,6 +358,7 @@ void add_symbols(GScanner *scanner){
     g_scanner_add_symbol(scanner,"band_lo", GINT_TO_POINTER(SYMBOL_BAND_LO)); 
     g_scanner_add_symbol(scanner,"band_sw", GINT_TO_POINTER(SYMBOL_BAND_SW)); 
     g_scanner_add_symbol(scanner,"opsect", GINT_TO_POINTER(SYMBOL_OPSECT)); 
+    g_scanner_add_symbol(scanner,"wwlradius", GINT_TO_POINTER(SYMBOL_WWLRADIUS)); 
     
     g_scanner_add_symbol(scanner,"as_disk_qso",     GINT_TO_POINTER(SYMBOL_AS_DAQ)); 
     g_scanner_add_symbol(scanner,"as_disk_min",     GINT_TO_POINTER(SYMBOL_AS_DAM)); 
@@ -471,6 +478,7 @@ void add_symbols(GScanner *scanner){
     g_scanner_add_symbol(scanner,"rig_filename",        GINT_TO_POINTER(SYMBOL_RIG_FILENAME)); 
     g_scanner_add_symbol(scanner,"rig_model",           GINT_TO_POINTER(SYMBOL_RIG_MODEL)); 
     g_scanner_add_symbol(scanner,"rig_speed",           GINT_TO_POINTER(SYMBOL_RIG_SPEED)); 
+	g_scanner_add_symbol(scanner,"rig_handshake_none",  GINT_TO_POINTER(SYMBOL_RIG_HANDSHAKE_NONE)); 
     g_scanner_add_symbol(scanner,"rig_civaddr",         GINT_TO_POINTER(SYMBOL_RIG_CIVADDR)); 
     g_scanner_add_symbol(scanner,"rig_lo",              GINT_TO_POINTER(SYMBOL_RIG_LO)); 
     g_scanner_add_symbol(scanner,"rig_ssbcw_shift",     GINT_TO_POINTER(SYMBOL_RIG_SSBCW_SHIFT)); 
@@ -502,6 +510,7 @@ void add_symbols(GScanner *scanner){
     g_scanner_add_symbol(scanner,"nolocks",          GINT_TO_POINTER(SYMBOL_NOLOCKS));
 	g_scanner_add_symbol(scanner,"portrait",         GINT_TO_POINTER(SYMBOL_PORTRAIT));
 	g_scanner_add_symbol(scanner,"reverse",          GINT_TO_POINTER(SYMBOL_REVERSE));
+	g_scanner_add_symbol(scanner,"inverse",          GINT_TO_POINTER(SYMBOL_INVERSE));
 
 	g_scanner_add_symbol(scanner,"dxc_host",       GINT_TO_POINTER(SYMBOL_DXC_HOST));
 	g_scanner_add_symbol(scanner,"dxc_port",       GINT_TO_POINTER(SYMBOL_DXC_PORT));
@@ -543,6 +552,9 @@ void add_symbols(GScanner *scanner){
 	g_scanner_add_symbol(scanner,"sdr_pcm_rec",       GINT_TO_POINTER(SYMBOL_SDR_PCM_REC));
 	g_scanner_add_symbol(scanner,"sdr_pcm_play",      GINT_TO_POINTER(SYMBOL_SDR_PCM_PLAY));
 	g_scanner_add_symbol(scanner,"sdr_sndfilename",   GINT_TO_POINTER(SYMBOL_SDR_SNDFILENAME));
+	g_scanner_add_symbol(scanner,"sdr_remoterx",   GINT_TO_POINTER(SYMBOL_SDR_REMOTERX));
+	g_scanner_add_symbol(scanner,"sdr_af_filename",   GINT_TO_POINTER(SYMBOL_SDR_AF_FILENAME));
+	g_scanner_add_symbol(scanner,"sdr_iqcomp",      GINT_TO_POINTER(SYMBOL_SDR_IQCOMP));
 
 	g_scanner_add_symbol(scanner,"wiki_url",    GINT_TO_POINTER(SYMBOL_WIKI_URL));
 	g_scanner_add_symbol(scanner,"wiki_user",   GINT_TO_POINTER(SYMBOL_WIKI_USER));
@@ -969,6 +981,7 @@ guint read_one_token(GScanner *scanner){
                 g_ptr_array_add(cfg->bands, cfg->band); 
                 cfg->band->pband = fixsemi(g_strdup(scanner->value.v_string));
                 cfg->band->skedqrg=g_strdup("");
+                cfg->band->wwlradius = 10;
             }
             //dbg("new band: '%s' cfg->band='%p' \n", scanner->value.v_string,cfg->band);
             
@@ -1011,6 +1024,7 @@ guint read_one_token(GScanner *scanner){
         STORE_RC_DOUBLE   (cfg->band, SYMBOL_BAND_LO, band_lo);
         STORE_RC_INT      (cfg->band, SYMBOL_BAND_SW,  band_sw);
         STORE_RC_STRING   (cfg->band, SYMBOL_OPSECT,  opsect);
+        STORE_RC_INT      (cfg->band, SYMBOL_WWLRADIUS,  wwlradius);
 
         STORE_RC_INT      (cfg, SYMBOL_CWDA_TYPE,    cwda_type);
         STORE_RC_STRING   (cfg, SYMBOL_CWDA_DEVICE,  cwda_device);
@@ -1088,6 +1102,7 @@ guint read_one_token(GScanner *scanner){
 		STORE_RC_STRING   (cfg->crig, SYMBOL_RIG_DESC, rig_desc);
         STORE_RC_INT      (cfg->crig, SYMBOL_RIG_MODEL, rig_model);
         STORE_RC_INT      (cfg->crig, SYMBOL_RIG_SPEED, rig_speed);
+		STORE_RC_INT      (cfg->crig, SYMBOL_RIG_HANDSHAKE_NONE, rig_handshake_none);
         STORE_RC_INT      (cfg->crig, SYMBOL_RIG_CIVADDR, rig_civaddr);
         STORE_RC_DOUBLE   (cfg->crig, SYMBOL_RIG_LO, rig_lo);
         STORE_RC_INT      (cfg->crig, SYMBOL_RIG_SSBCW_SHIFT, rig_ssbcw_shift);
@@ -1173,6 +1188,7 @@ guint read_one_token(GScanner *scanner){
         STORE_RC_INT   (cfg, SYMBOL_NOLOCKS,     nolocks);
         STORE_RC_INT   (cfg, SYMBOL_PORTRAIT,    portrait);
         STORE_RC_INT   (cfg, SYMBOL_REVERSE,     reverse);
+        STORE_RC_INT   (cfg, SYMBOL_INVERSE,     inverse);
 
 		STORE_RC_STRING(cfg, SYMBOL_DXC_HOST, dxc_host);
 		STORE_RC_INT   (cfg, SYMBOL_DXC_PORT, dxc_port);
@@ -1214,6 +1230,9 @@ guint read_one_token(GScanner *scanner){
 		STORE_RC_STRING(cfg, SYMBOL_SDR_PCM_REC, sdr_pcm_rec);
         STORE_RC_STRING(cfg, SYMBOL_SDR_PCM_PLAY, sdr_pcm_play);
 		STORE_RC_STRING(cfg, SYMBOL_SDR_SNDFILENAME, sdr_sndfilename);
+		STORE_RC_STRING(cfg, SYMBOL_SDR_REMOTERX, sdr_remoterx);
+		STORE_RC_STRING(cfg, SYMBOL_SDR_AF_FILENAME, sdr_af_filename);
+		STORE_RC_INT   (cfg, SYMBOL_SDR_IQCOMP, sdr_iqcomp);
 
 		STORE_RC_STRING(cfg, SYMBOL_WIKI_URL, wiki_url);
 		STORE_RC_STRING(cfg, SYMBOL_WIKI_USER, wiki_user);
@@ -1314,7 +1333,7 @@ gint read_rc_file(gchar *filename, const char *text){
    if (buf) g_free(buf);
 /*   dbg("call %s\n", cfg->call);*/
    if (errors){
-       log_addf(VTEXT(T_FOUND_D_ERRORS),errors, errors>1?"s":"",filename);
+       log_addf(CTEXT(T_FOUND_D_ERRORS),errors, errors>1?"s":"",filename);
        //dbg("Found %d error%s while reading %s\n",errors, errors>1?"s":"",filename);
        return errors;
    }
@@ -1428,6 +1447,14 @@ gint read_rc_files(void){
 #ifdef Z_ANDROID
 	  cfg->cwda_type = CWD_NONE;
       cfg->fullscreen = 1;
+#endif
+#ifdef Z_MSC_MINGW
+	  g_free(cfg->cwda_device);
+	  cfg->cwda_device = g_strdup("0x378");
+	  if (cfg->crig != NULL){
+		  g_free(cfg->crig->rig_filename);
+		  cfg->crig->rig_filename = g_strdup("COM3");
+	  }
 #endif
     }
     
@@ -1630,21 +1657,22 @@ void save_rc_string(GString *gs){
 		struct config_rig *crig;
 		crig = (struct config_rig *)g_ptr_array_index(cfg->crigs, i);
         g_string_sprintfa(gs, "RIG = %d\n", i);
-		g_string_sprintfa(gs, "    rig_enabled       = %d\n", crig->rig_enabled);
-		g_string_sprintfa(gs, "    rig_desc          = \"%s\"\n", S(crig->rig_desc));
-		g_string_sprintfa(gs, "    rig_filename      = \"%s\"\n", S(crig->rig_filename));
-		g_string_sprintfa(gs, "    rig_model         = %d\n", crig->rig_model);
-		g_string_sprintfa(gs, "    rig_speed         = %d\n", crig->rig_speed);
-		g_string_sprintfa(gs, "    rig_civaddr       = %d\n", crig->rig_civaddr);
-		g_string_sprintfa(gs, "    rig_lo            = %f\n", crig->rig_lo);
-		g_string_sprintfa(gs, "    rig_ssbcw_shift   = %d\n", crig->rig_ssbcw_shift);
-		g_string_sprintfa(gs, "    rig_poll_ms       = %d\n", crig->rig_poll_ms);
-		g_string_sprintfa(gs, "    rig_qrg_r2t       = %d\n", crig->rig_qrg_r2t);
-		g_string_sprintfa(gs, "    rig_qrg_t2r       = %d\n", crig->rig_qrg_t2r);
-		g_string_sprintfa(gs, "    rig_mode_t2r      = %d\n", crig->rig_mode_t2r);
-		g_string_sprintfa(gs, "    rig_clr_rit       = %d\n", crig->rig_clr_rit);
-		g_string_sprintfa(gs, "    rig_ptt_t2r       = %d\n", crig->rig_ptt_t2r);
-		g_string_sprintfa(gs, "    rig_verbose       = %d\n", crig->rig_verbose);
+		g_string_sprintfa(gs, "    rig_enabled        = %d\n", crig->rig_enabled);
+		g_string_sprintfa(gs, "    rig_desc           = \"%s\"\n", S(crig->rig_desc));
+		g_string_sprintfa(gs, "    rig_filename       = \"%s\"\n", S(crig->rig_filename));
+		g_string_sprintfa(gs, "    rig_model          = %d\n", crig->rig_model);
+		g_string_sprintfa(gs, "    rig_speed          = %d\n", crig->rig_speed);
+		g_string_sprintfa(gs, "    rig_handshake_none = %d\n", crig->rig_verbose);
+		g_string_sprintfa(gs, "    rig_civaddr        = %d\n", crig->rig_civaddr);
+		g_string_sprintfa(gs, "    rig_lo             = %f\n", crig->rig_lo);
+		g_string_sprintfa(gs, "    rig_ssbcw_shift    = %d\n", crig->rig_ssbcw_shift);
+		g_string_sprintfa(gs, "    rig_poll_ms        = %d\n", crig->rig_poll_ms);
+		g_string_sprintfa(gs, "    rig_qrg_r2t        = %d\n", crig->rig_qrg_r2t);
+		g_string_sprintfa(gs, "    rig_qrg_t2r        = %d\n", crig->rig_qrg_t2r);
+		g_string_sprintfa(gs, "    rig_mode_t2r       = %d\n", crig->rig_mode_t2r);
+		g_string_sprintfa(gs, "    rig_clr_rit        = %d\n", crig->rig_clr_rit);
+		g_string_sprintfa(gs, "    rig_ptt_t2r        = %d\n", crig->rig_ptt_t2r);
+		g_string_sprintfa(gs, "    rig_verbose        = %d\n", crig->rig_verbose);
 		g_string_sprintfa(gs, "\n");
 	}
     g_string_sprintfa(gs, "\n");
@@ -1668,6 +1696,7 @@ void save_rc_string(GString *gs){
     g_string_sprintfa(gs, "nolocks         = %d\n", cfg->nolocks);
     g_string_sprintfa(gs, "portrait        = %d\n", cfg->portrait);
     g_string_sprintfa(gs, "reverse         = %d\n", cfg->reverse);
+    g_string_sprintfa(gs, "inverse         = %d\n", cfg->inverse);
     for (i=0; i<cfg->takeoff->len;i++){
         struct takeoff *toff;
         toff=(struct takeoff*)g_ptr_array_index(cfg->takeoff, i);
@@ -1721,7 +1750,13 @@ void save_rc_string(GString *gs){
 	z_unix(fpath);
 	g_string_sprintfa(gs, "sdr_sndfilename = \"%s\"\n", fpath);
 	g_free(fpath);
-    g_string_sprintfa(gs, "\n");
+	g_string_sprintfa(gs, "sdr_remoterx = \"%s\"\n", S(cfg->sdr_remoterx));
+    fpath = g_strdup(S(cfg->sdr_af_filename));
+	z_unix(fpath);
+	g_string_sprintfa(gs, "sdr_af_filename = \"%s\"\n", fpath);
+	g_free(fpath);
+	g_string_sprintfa(gs, "sdr_iqcomp = %d\n", cfg->sdr_iqcomp);
+	g_string_sprintfa(gs, "\n");
 
     g_string_sprintfa(gs, "wiki_url = \"%s\"\n", S(cfg->wiki_url));
     g_string_sprintfa(gs, "wiki_user = \"%s\"\n", S(cfg->wiki_user));
@@ -1802,6 +1837,7 @@ void save_rc_string(GString *gs){
         g_string_sprintfa(gs, "    skedqrg   = \"%s\"\n", S(b->skedqrg));
         g_string_sprintfa(gs, "    band_lo   = %f\n", b->band_lo);
         g_string_sprintfa(gs, "    band_sw   = 0x%02x\n", b->band_sw);
+        g_string_sprintfa(gs, "    wwlradius = %d\n", b->wwlradius);
         g_string_sprintfa(gs, "\n");
     }
 }
