@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011-2015 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2016 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -35,6 +35,7 @@ struct config_band{
     gchar *skedqrg;
     gdouble band_lo;
     int band_sw;
+    int wwlradius;
 };
 
 struct config {   /* depending on callsign */
@@ -107,7 +108,7 @@ struct config {   /* depending on callsign */
     int global_operator;
     gchar *operator_;
 	int gfx_x, gfx_y, ntpq, dssaver, splitheight, fullscreen, maximized;
-	int usetouch, touchpos, altsyms, nolocks, portrait, reverse;
+	int usetouch, touchpos, altsyms, nolocks, portrait, reverse, inverse;
 
     int fontheight;
     char *slashkey;
@@ -131,11 +132,11 @@ struct config {   /* depending on callsign */
     double ac_maxdelta;  // max difference of incidence and reflection angles
 	int ac_minalt;       // minimal AC altitude to show on map in meters
 
-	int sdr_enable, sdr_cw, sdr_lsb, sdr_speed, sdr_af_speed, sdr_block;
+	int sdr_enable, sdr_cw, sdr_lsb, sdr_speed, sdr_af_speed, sdr_block, sdr_iqcomp;
 	double sdr_zero, sdr_cw_low, sdr_cw_high, sdr_ssb_low, sdr_ssb_high;
 	int sdr_rec_dsp_type, sdr_play_dsp_type;
     int sdr_pa_play, sdr_pa_rec;
-	char *sdr_pcm_play, *sdr_pcm_rec, *sdr_sndfilename;
+	char *sdr_pcm_play, *sdr_pcm_rec, *sdr_sndfilename, *sdr_remoterx, *sdr_af_filename;
 
 	char *wiki_url, *wiki_user, *wiki_pass, *wiki_page;
 	int wiki_map, wiki_chart, wiki_overwrite;
