@@ -68,6 +68,9 @@ int sw_sdr_kbd_func(struct subwin *sw, struct event *ev, int fw){
 		case 'u':
 		case 'U':
 			sdr_usb(sw);
+		case 'q':
+		case 'Q':
+			sdr_iqcomp(sw);
 			break;
 	}
     return 0;
@@ -97,7 +100,7 @@ int sw_sdr_mouse_func(struct subwin *sw, struct event *ev, int fw){
 		return 0;
 	} */
 
-	dbg("ev->b = 0x%04x\n", ev->b);
+	//dbg("ev->b = 0x%04x\n", ev->b);
 	if ((ev->b & B_DRAG) != 0  &&  (ev->b & BM_EBUTT) == B_RIGHT){
 		//if (sw->my < sw->fft_wf_y + sw->fft_wf_h){
 		if (sw->my < sw->fft_sp_y + sw->fft_sp_h){
@@ -106,7 +109,7 @@ int sw_sdr_mouse_func(struct subwin *sw, struct event *ev, int fw){
 				SDL_Rect r;
 
 				double df = DX2DF(dx);
-				dbg("sdr dx=%d  = %f hz\n", dx, df);
+				//dbg("sdr dx=%d  = %f hz\n", dx, df);
 #ifdef HAVE_HAMLIB
 				trigs_set_qrg(gtrigs, gtrigs->qrg - df);
 #endif
@@ -254,6 +257,12 @@ struct sdr *init_sdr(void){
 	sdr->nea_amp = g_new0(double, sdr->amplen);
 	sdr->sndbuf = g_new0(short, sdr->frames * 2);
 
+	sdr->bal_gain = 1.0;
+	sdr->bal_phase = 0.0;
+    sdr->bal_iq = (fftw_complex*)fftw_malloc(sizeof(fftw_complex) * SDR_BAL_N);
+    sdr->bal_bins = (fftw_complex*)fftw_malloc(sizeof(fftw_complex) * SDR_BAL_N);
+	sdr->bal_plan = fftw_plan_dft_1d(SDR_BAL_N, sdr->bal_bins, sdr->bal_bins, FFTW_FORWARD, FFTW_ESTIMATE);
+
 	dbg("init_sdr=%p\n", sdr);
 
 	return sdr;
@@ -491,6 +500,16 @@ void sdr_usb(void *xxx){
 	redraw_later();
 }
 
+void sdr_iqcomp(void *xxx){
+	struct subwin *sw = (struct subwin *)xxx;
+	dbg("sdr_iqcomp\n");
+
+	cfg->sdr_iqcomp = !cfg->sdr_iqcomp;
+	sw->sdr_iqcomp->bcolor = cfg->sdr_iqcomp ? gsdr->butbg : 0; 
+
+	redraw_later();
+}
+
 void sdr_lsb(void *xxx){
 	struct subwin *sw = (struct subwin *)xxx;
 	dbg("sdr_lsb\n");
@@ -561,6 +580,10 @@ void sdr_resize(struct sdr *sdr, struct subwin *sw){
 	button_text(sw->sdr_lsb, zsdl->font_h, sdl->gr[14], cfg->sdr_lsb ? sdr->butbg : 0, " LSB ");
 	g_ptr_array_add(sw->buttons, sw->sdr_lsb);
 
+	sw->sdr_iqcomp = init_button(sw->screen, sw->sdr_lsb->x + sw->sdr_lsb->w + zsdl->font_w, sw->sdr_by, sdr_iqcomp, sw);
+	button_text(sw->sdr_iqcomp, zsdl->font_h, sdl->gr[14], cfg->sdr_iqcomp ? sdr->butbg : 0, " IQcomp ");
+	g_ptr_array_add(sw->buttons, sw->sdr_iqcomp);
+
 	g_free(sdr->wfvec);
 	sdr->wfvec = g_new0(int, sw->screen->w);
 	sdr->wfveclen = sw->screen->w;
@@ -754,7 +777,7 @@ void sw_sdr_redraw(struct subwin *sw, struct band *band, int flags){
 	if (gtrigs) qrg += gtrigs->qrg;
 #endif
 	z_qrg_format(s, sizeof(s), qrg);
-	zsdl_printf(sw->screen, sw->sdr_lsb->x + sw->sdr_lsb->w + 3 * zsdl->font_w, sw->sdr_by, sdl->gr[14], 0, 0, "%s", s);
+	zsdl_printf(sw->screen, sw->sdr_iqcomp->x + sw->sdr_iqcomp->w + 3 * zsdl->font_w, sw->sdr_by, sdl->gr[14], 0, 0, "%s", s);
 
 	if (gsdr->load > -1){
 		zsdl_printf(sw->screen, sw->screen->w - 1, sw->sdr_by, sdl->gr[14], 0, ZFONT_RIGHT,  " CPU %d%%", gsdr->load);
@@ -775,7 +798,7 @@ gpointer sdr_thread_func(gpointer data){
 	double totsum = 0.0, cpusum = 0.0;
 	int loadn = 0;
 	short *buf, *b;
-	double *pd;
+	double *pd, avgi = 0.0, avgq = 0.0;
 	int playspeed, playfactor;
 	int use_pipe = 0;
 
@@ -818,7 +841,7 @@ gpointer sdr_thread_func(gpointer data){
 	sdr->agc_period_ms = 1;
 	sdr->agc_n = sdr->samplerate * sdr->agc_period_ms / 1000.0;
 	sdr->agc_ign = sdr->samplerate * 100 / ( 1000.0 * sdr->agc_n); 
-	buf = g_new0(short, sdr->frames * sdr->iqdsp->channels);
+	buf = g_new0(short, sdr->frames * sdr->iqdsp->channels); // nem bt sdr->samples?
 
 	memset(sdr->iq, 0, sizeof(fftw_complex) * sdr->n);
 	gettimeofday(&tv1, NULL);
@@ -844,7 +867,7 @@ gpointer sdr_thread_func(gpointer data){
 		frames = sdr->iqdsp->read(sdr->iqdsp, buf, sdr->frames);
 		//ST_STOP("dsp read");
 		if (frames != sdr->frames){
-			zselect_msg_send(zsel, "SDR;!;%s %s (%d != %d)", VTEXT(T_CANT_READ_FROM), sdr->iqdsp->name, frames, sdr->frames);
+			zselect_msg_send(zsel, "SDR;!;%s SDR IQDSP %s (%d != %d)", VTEXT(T_CANT_READ_FROM), sdr->iqdsp->name, frames, sdr->frames);
             break;
         }
 
@@ -854,10 +877,22 @@ gpointer sdr_thread_func(gpointer data){
         
 		b = buf;
 		pd = (double*)(sdr->iq + (sdr->n - sdr->frames));
-		for (i = 0; i < sdr->samples; i++){
-			*pd++ = *b++ / 32767.0;
+		for (i = 0; i < sdr->frames; i++){
+			*pd = *b / 32767.0;
+			if (cfg->sdr_iqcomp){
+				avgi += 0.00001 * (*pd - avgi);
+				*pd -= avgi;
+			}
+			pd++, b++;
+			*pd = *b / 32767.0;
+			if (cfg->sdr_iqcomp){
+				avgq += 0.00001 * (*pd - avgq);
+				*pd -= avgq;
+			}
+			pd++, b++;
 		}
 
+		sdr_bal_adjust(sdr, sdr->iq, sdr->frames, sdr->bal_gain, sdr->bal_phase);
         
 		fftw_execute(sdr->plan_f);
     
@@ -991,7 +1026,7 @@ gpointer sdr_thread_func(gpointer data){
 				if (idx >= sdr->frames) break;
 				max = Z_MAX(max, fabs(sdr->iout[idx][0]));
 			}
-			max = max;
+			//max = max; why?
 			g = 0.5 / max;
 			oldgain = sdr->agc_gain;
 			if (g < sdr->agc_gain){ // decrease gain
@@ -1071,4 +1106,22 @@ gpointer sdr_thread_func(gpointer data){
 #endif
 	return NULL;
 }
-#endif
+
+void sdr_balance(struct sdr *sdr){
+	//if (!sdr->iqcomp) return;
+
+	memcpy(sdr->bal_iq, sdr->iq, sizeof(fftw_complex) * SDR_BAL_N);
+	fftw_execute(sdr->bal_plan);
+
+} 
+
+void sdr_bal_adjust(struct sdr *sdr, fftw_complex *iq, int len, double gain, double phase){
+	int i;
+
+	for (i = 0; i < len; i++){
+		iq[i][0] = iq[i][0] * gain + iq[i][1] * phase;
+	}
+
+}
+
+#endif // USE_SDR
