@@ -956,7 +956,8 @@ void add_sf_wkd_wwls(struct band *b){
     fifo_addf(F, VTEXT(T_SF_WKD_WWLS_UNDER));
     
     w=term->x - 2;
-    len = w / 5;
+    dbg("b->wwlradius=%d   w/5=%d\n", b->wwlradius, w/5);
+    len = Z_MIN(b->wwlradius * 2 + 1, w / 5);
     lines = len;
     
     myh = qthwr(ctest->pwwlo, 0);
@@ -972,7 +973,7 @@ void add_sf_wkd_wwls(struct band *b){
             char s[10];
             int aw, ah;
             
-            aw = lines-i - lines/2; 
+            aw = lines - i - 1 - lines/2; 
             ah = j - len/2;
 
             if (aw==0 && ah==0){
@@ -1003,7 +1004,7 @@ void add_sf_cnt_in_wwls(struct band *b){
     fifo_addf(F, VTEXT(T_SF_QSO_WWL4_UNDER));
     
     w=term->x - 2;
-    len = w / 5;
+    len = Z_MIN(b->wwlradius * 2 + 1, w / 5);
     lines = len;
     
     myh = qthwr(ctest->pwwlo, 0);
@@ -1021,7 +1022,7 @@ void add_sf_cnt_in_wwls(struct band *b){
             int aw, ah;
             
             
-            aw = lines-i - lines/2; 
+            aw = lines - i - 1 - lines/2; 
             ah = j - len/2;
 
             mkwwl4(s, aw+ myw , ah + myh);
