@@ -725,10 +725,12 @@ test_queue:
     goto test_queue;
 }
 
-inline int getcompcode(int c)
+/*inline int getcompcode(int c) // probably bug in gcc 4.6
 {
     return (c<<1 | (c&4)>>2) & 7;
-}
+}*/
+#define getcompcode(c) (int)( ((c)<<1 | ((c)&4)>>2) & 7 )
+
 
 char frame_dumb[49] =  "   ||||++||++++++--|-+||++--|-+----++++++++     ";
 char frame_vt100[49] = "aaaxuuukkuxkjjjkmvwtqnttmlvwtqnvvwwmmllnnjla    ";
