@@ -362,7 +362,7 @@ int sdl_setvideomode(int w, int h, int init_x){
 		return 1;    
 	}
 
-	zsdl = zsdl_init(sdl->screen, cfg->fontheight);
+	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse);
     //if (SDL_MUSTLOCK(sdl->screen)) zinternal("surface must be locked");
     sdl->termarea.x = 0;
     sdl->termarea.y = 0;
@@ -856,6 +856,9 @@ gpointer sdl_event_thread(gpointer handle){
                 dbg("type=%d state=%d scan=%d sym=%d mod=%d unicode=%d\n", 
                         sev.key.type, sev.key.state, sev.key.keysym.scancode, sev.key.keysym.sym, sev.key.keysym.mod, sev.key.keysym.unicode);
                 dbg("%d %d\n", SDLK_LCTRL, SDLK_RCTRL);
+				if (sev.key.keysym.unicode == 43){
+					int aaa = 0;
+				}
 #endif                
 				
 				if (sev.key.keysym.sym == SDLK_LCTRL || sev.key.keysym.sym == SDLK_RCTRL) {
@@ -930,7 +933,11 @@ gpointer sdl_event_thread(gpointer handle){
                 }
 
                 skip_unicode = 0;
-                if (sev.key.keysym.sym >= SDLK_0 && sev.key.keysym.sym <= SDLK_9 && sev.key.keysym.mod & KMOD_CTRL) skip_unicode = 1; // Ctrl+3 to Ctrl+9 send strange unicode values
+                if (sev.key.keysym.sym >= SDLK_0 && sev.key.keysym.sym <= SDLK_9 
+					&& sev.key.keysym.mod & KMOD_CTRL    // Ctrl+3 to Ctrl+9 send strange unicode values
+					&& (sev.key.keysym.mod & KMOD_RALT) == 0) { // but right Alt sets LCTRL | RALT
+						skip_unicode = 1; 
+				}
 
                 if (sev.key.keysym.unicode && !skip_unicode){
                     if (handle_unicode(&sev, &ev)) goto sendkeydown;
@@ -986,7 +993,7 @@ handle:;
                     ev.x=k;
                 }
 
-                if (sev.key.keysym.mod & (KMOD_ALT|KMOD_META)){
+                if (sev.key.keysym.mod & (KMOD_LALT|KMOD_META)){
                     ev.y|=KBD_ALT;
                 }
                     
@@ -1418,6 +1425,7 @@ void tsdl_change_font(char how){
 }
 
 void tsdl_optimal_font(){
+    if (!sdl) return;
 	
 	if (sdl->screen_w >= 1920 && sdl->screen_h >= 1080){
 		cfg->fontheight = 32;
@@ -1431,4 +1439,5 @@ void tsdl_optimal_font(){
 	resize_terminal(NULL);
 }
 
+
 #endif
